.. _get_started:

Getting Started
===============

SymPy is a Python library for symbolic mathematics. It aims to become a full-featured computer
algebra system (CAS) while keeping the code as simple as possible in order to be comprehensible
and easily extensible. SymPy is written entirely in Python.

SymPy is…

- **Free**: Licensed under BSD, SymPy is free both as in speech and as in beer.
- **Python-based**: SymPy is written entirely in Python and uses Python for its language.
- **Lightweight**: SymPy only depends on mpmath, a pure Python library for arbitrary floating point arithmetic, making it easy to use.
- **A library**: Beyond use as an interactive tool, SymPy can be embedded in other applications and extended with custom functions.

.. toctree::

   install.rst
